//+------------------------------------------------------------------+
//|                                               FractalsPeriod.mq5 |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Alexander Piechotta"
#property link      "setchar@googlemail.com"
#property version   "2.00"
#property description "FractalsPeriod - Anzahl der Bars vor und nach"
#property description "dem aktuellen Hoch/Tief(ermittelt Fraktal)"
#property strict
#property indicator_chart_window
#property indicator_buffers 2
#property indicator_plots   2

//---- plot Fractal Up
#property indicator_label1  "Fractal Up"
#property indicator_type1   DRAW_ARROW
#property indicator_color1  Blue
#property indicator_style1  STYLE_SOLID
#property indicator_width1  2

//---- plot Fractal Down
#property indicator_label2  "Fractal Down"
#property indicator_type2   DRAW_ARROW
#property indicator_color2  Blue
#property indicator_style2  STYLE_SOLID
#property indicator_width2  2

//--- indicator buffers
double  upper_fr[];
double  lower_fr[];

//--- 10 pixels upper from high price
int    ExtArrowShift=-10;

//--- input parameters
input bool CompleteBarsOnly=true;      //  
input int  FractalsPeriodBefore=15;    // 
input int  FractalsPeriodAfter=25;     // 
input int  MaxBars=1000;               //   
input int  TrenLine=15;                //    
//input int  countBars=15;
string _name="fractal_";
//
#include <CalcFrac.mqh>

CalcFrac Higher,Lower;
bool probitieH=false,probitieL=false;
double ph=0,pl=0;
datetime th=0,tl=0, arr[];
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
void OnInit()
  {

//--- indicator buffers mapping
   SetIndexBuffer(0,upper_fr,INDICATOR_DATA);
   SetIndexBuffer(1,lower_fr,INDICATOR_DATA);

   IndicatorSetInteger(INDICATOR_DIGITS,_Digits);
//---- sets first bar from what index will be drawn
   PlotIndexSetInteger(0,PLOT_ARROW,115);
   PlotIndexSetInteger(1,PLOT_ARROW,115);
//---- arrow shifts when drawing   
   PlotIndexSetInteger(0,PLOT_ARROW_SHIFT,ExtArrowShift);
   PlotIndexSetInteger(1,PLOT_ARROW_SHIFT,-ExtArrowShift);
//---- sets drawing line empty value--
   PlotIndexSetDouble(0,PLOT_EMPTY_VALUE,0.0);
   PlotIndexSetDouble(1,PLOT_EMPTY_VALUE,0.0);

   Lower.before_period =FractalsPeriodBefore;
   Lower.after_period  =FractalsPeriodAfter;
   Higher.before_period=FractalsPeriodBefore;
   Higher.after_period =FractalsPeriodAfter;
//---- initialization done

  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   for(int i = ObjectsTotal(ChartID(), 0)-1; i>=0; i--)
   {
      if(StringFind(ObjectName(ChartID(), i, 0), _name)>=0)
         ObjectDelete(ChartID(), ObjectName(ChartID(), i));
   }
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
  {

   int Limit;

   if(rates_total<5) return(0);
     
   if(CopyLow(NULL,NULL,0,rates_total,Lower.values)<=0)
     {
      Print("Getting Low data is failed! Error",GetLastError());
      return(0);
     }

   if(CopyHigh(NULL,NULL,0,rates_total,Higher.values)<=0)
     {
      Print("Getting High data is failed! Error",GetLastError());
      return(0);
     }

   Limit=(int)MathAbs(fmin(rates_total,MaxBars)-rates_total);
   if(prev_calculated<5)
     {
      //buffers cleanup 
      ArrayInitialize(upper_fr,0.0);
      ArrayInitialize(lower_fr,0.0);
     }

   for(int i=Limit+FractalsPeriodBefore;i<rates_total-FractalsPeriodAfter-CompleteBarsOnly;i++)
     {
      //Fractals calculated and show 
      if(Higher.is_upper_fr(i))
        {
         //ph = high[i];
         //th = time[i];
         //upper_fr[i]=high[i];
         //probitieH=true;
         TrendCreate(0, _name+"H"+TimeToString(time[i], TIME_DATE|TIME_MINUTES), 0, time[i], high[i], EndTrena(time[i]), high[i], clrDeepSkyBlue);
         //UpperTrend(ph,th,open[i],close[i],EndTrena(time[i]));
        }
      else upper_fr[i]=0.;
      //if(probitieH) UpperTrend(ph,th,open[i],close[i],EndTrena(time[i]));
      if(Lower.is_lower_fr(i))
        {
         //pl = low[i];
         //tl = time[i];
         //lower_fr[i]=low[i];
         //probitieL=true;
         TrendCreate(0, _name+"L"+TimeToString(time[i], TIME_DATE|TIME_MINUTES), 0, time[i], low[i], EndTrena(time[i]), low[i], clrOrange);
         //LowerTrend(pl,tl,open[i],close[i],EndTrena(time[i]));
        }
      else lower_fr[i]=0.;
      //if(probitieL)LowerTrend(pl,tl,open[i],close[i],EndTrena(time[i]));
     }

//--- OnCalculate done. Return new prev_calculated. 
   return(rates_total);
  }

//+------------------------------------------------------------------+
void TrendCreate(const long            chart_ID=0,// ID 
                 const string          name1="TrendLine",//  
                 const int             sub_window=0,      //  
                 datetime              time1=0,           //   
                 double                price1=0,          //   
                 datetime              time2=0,           //   
                 double                price2=0,          //   
                 const color           clr=clrRed,        //  
                 const ENUM_LINE_STYLE style=STYLE_SOLID, //  
                 const int             width=2,           //  
                 const bool            back=true,//   
                 const bool            selection=true,//   
                 const bool            ray_right=false,//   
                 const bool            hidden=false,//    
                 const long            z_order=0) //    
  {

//---   
   ResetLastError();
//---      
   ObjectCreate(chart_ID,name1,OBJ_TREND,sub_window,time1,price1,time2,price2);
//---   
   ObjectSetInteger(chart_ID,name1,OBJPROP_COLOR,clr);
//---    
   ObjectSetInteger(chart_ID,name1,OBJPROP_STYLE,style);
//---   
   ObjectSetInteger(chart_ID,name1,OBJPROP_WIDTH,width);
//---    (false)   (true) 
   ObjectSetInteger(chart_ID,name1,OBJPROP_BACK,back);
//---  (true)   (false)    
//---      ObjectCreate,   
//---    .      selection
//---    true,       
   ObjectSetInteger(chart_ID,name1,OBJPROP_SELECTABLE,selection);
   ObjectSetInteger(chart_ID,name1,OBJPROP_SELECTED,selection);
//---  (true)   (false)     
   ObjectSetInteger(chart_ID,name1,OBJPROP_RAY_RIGHT,ray_right);
//---  (true)   (false)      
   ObjectSetInteger(chart_ID,name1,OBJPROP_HIDDEN,hidden);
//---         
   ObjectSetInteger(chart_ID,name1,OBJPROP_ZORDER,z_order);
  }
//+------------------------------------------------------------------+
/*void UpperTrend(double _priceH,datetime _timeH,double _priceO,double _priceC,datetime timeCurr)
  {
   if(!probitieH)return;
   if(_priceO<=_priceH && _priceC>=_priceH)
     {
      TrendCreate(0,_name+"H"+TimeToString(_timeH,TIME_DATE|TIME_MINUTES),0,_timeH,_priceH,timeCurr,_priceH,clrDeepSkyBlue);
      probitieH=false;
     }
  }
//+------------------------------------------------------------------+
void LowerTrend(double _priceL,datetime _timeL,double _priceO,double _priceC,datetime timeCurr)
  {
   if(!probitieL)return;
   if(_priceO>=_priceL && _priceC<=_priceL)
     {
      TrendCreate(0,_name+"H"+TimeToString(_timeL,TIME_DATE|TIME_MINUTES),0,_timeL,_priceL,timeCurr,_priceL,clrOrange);
      probitieL=false;
     }
  }*/
//+------------------------------------------------------------------+
datetime EndTrena(datetime start)
{
   long s = (long)start;
   long r = s + (PeriodSeconds() * TrenLine);
   datetime ret=(datetime)r;
   return ret;
}
//+------------------------------------------------------------------+